Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(22)

Unified Diff: chrome/browser/ui/intents/web_intent_picker_controller.h

Issue 8934011: Rename IntentsHost -> WebIntentsDispatcher and IntentsDispatcher -> WebIntentsHost. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Merge to head Created 9 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/browser.cc ('k') | chrome/browser/ui/intents/web_intent_picker_controller.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/intents/web_intent_picker_controller.h
diff --git a/chrome/browser/ui/intents/web_intent_picker_controller.h b/chrome/browser/ui/intents/web_intent_picker_controller.h
index a045c4cc97a873e5c751086d95cab827ce2305de..eb5e7a3f7be1e8999abb355afde4653b9f2050e6 100644
--- a/chrome/browser/ui/intents/web_intent_picker_controller.h
+++ b/chrome/browser/ui/intents/web_intent_picker_controller.h
@@ -25,7 +25,7 @@ class WebIntentPicker;
class WebIntentPickerFactory;
namespace content {
-class IntentsHost;
+class WebIntentsDispatcher;
}
namespace webkit_glue {
@@ -43,9 +43,9 @@ class WebIntentPickerController : public content::NotificationObserver,
virtual ~WebIntentPickerController();
// Sets the intent data and return pathway handler object for which
- // this picker was created. The picker takes ownership of |intents_host|.
- // |intents_host| must not be NULL.
- void SetIntentsHost(content::IntentsHost* intents_host);
+ // this picker was created. The picker takes ownership of
+ // |intents_dispatcher|. |intents_dispatcher| must not be NULL.
+ void SetIntentsDispatcher(content::WebIntentsDispatcher* intents_dispatcher);
// Shows the web intent picker for |browser|, given the intent
// |action| and MIME-type |type|.
@@ -120,7 +120,7 @@ class WebIntentPickerController : public content::NotificationObserver,
// The routing object for the renderer which launched the intent.
// Contains the intent data and a way to signal back to the client page.
- scoped_ptr<content::IntentsHost> intents_host_;
+ scoped_ptr<content::WebIntentsDispatcher> intents_dispatcher_;
// Weak pointer to the tab servicing the intent. Remembered in order to
// close it when a reply is sent.
« no previous file with comments | « chrome/browser/ui/browser.cc ('k') | chrome/browser/ui/intents/web_intent_picker_controller.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698